@@ -1,3 +1,41 @@
+//! # This crate is deprecated
+//! This crate can be replaced with [vob](https://crates.io/crates/vob) if you add this trait to your code:
+//!```rust
+//! // u32 is slightly faster for random access w/o any bit operations
+//! pub(crate) type VobU32 = vob::Vob<u32>;
+//!
+//! pub(crate) trait GrowingVob {
+//!    /// Will create a new Vob and fill it with `default`
+//!    fn fill(initial_size: usize, default:bool) -> VobU32;
+//!    /// Grow to fit new size, set ´bit´ to ´state´ value
+//!    fn set_grow(&mut self, bit: usize, state: bool) -> bool;
+//!    /// get() with default value `false`
+//!    fn get_f(&self, bit: usize) -> bool;
+//! }
+//!
+//! impl GrowingVob for VobU32 {
+//!    #[inline]
+//!    fn fill(initial_size: usize, default:bool) -> Self {
+//!        let mut v = Self::new_with_storage_type(0);
+//!        v.resize(initial_size, default);
+//!        v
+//!    }
+//!
+//!    #[inline]
+//!    fn set_grow(&mut self, bit: usize, state: bool) -> bool {
+//!        if bit >= self.len() {
+//!            self.resize(bit + 64, false);
+//!        }
+//!        self.set(bit, state)
+//!    }
+//!
+//!    #[inline]
+//!    fn get_f(&self, bit: usize) -> bool {
+//!        self.get(bit).unwrap_or(false)
+//!    }
+//!}
+//!```
+//!
 //! # Yabf
 //! Just what the world needed - yet another bit field struct.
 //!
@@ -21,7 +59,7 @@
 //! ```
 //!
 //! ```{rust}
-//!# #[cfg(feature = "impl_smallvec")] {
+//!# #[cfg(feature = "smallvec")] {
 //! use yabf::SmallYabf;
 //! let mut a = SmallYabf::default();
 //! let mut b = SmallYabf::with_capacity(12345);
@@ -44,8 +82,7 @@
 use core::fmt;
 use std::ops;
 
-
-#[derive(Clone)]
+#[derive(Clone, Default)]
 /// Yet another bit field implementation.
 /// This is a simple, small and hopefully efficient bit field implementation.
 ///
@@ -128,7 +165,11 @@ impl Yabf {
             for _i in old_word..word - 1 {
                 self.internals.push(0);
             }
-            self.internals.push(bit_mask);
+            if state {
+                self.internals.push(bit_mask);
+            } else {
+                self.internals.push(0);
+            }
         } else if state {
             self.internals[word] |= bit_mask;
         } else {
@@ -287,15 +328,6 @@ impl fmt::Debug for Yabf {
     }
 }
 
-impl Default for Yabf {
-    #[inline]
-    fn default() -> Self {
-        Self {
-            internals: Vec::<u32>::default(),
-        }
-    }
-}
-
 /// bit or assign operation.
 /// This is a relatively expensive O(size of container) operation.
 /// ```
@@ -337,7 +369,7 @@ impl ops::BitOrAssign<&Yabf> for Yabf {
     }
 }
 
-#[derive(Clone)]
+#[derive(Clone, Default)]
 /// Yet another bit field implementation.
 /// This is a simple, small and hopefully efficient bit field implementation. It uses SmallVec
 /// as an internal container. The first 128 bits will be stored on the stack.
@@ -345,12 +377,12 @@ impl ops::BitOrAssign<&Yabf> for Yabf {
 /// It is intended for cases where a program iterates over list or other usize indexed containers
 /// and simple bit based bookkeeping is required.
 ///
-#[cfg(feature = "impl_smallvec")]
+#[cfg(feature = "smallvec")]
 pub struct SmallYabf {
     internals: smallvec::SmallVec<[u32; 4]>,
 }
 
-#[cfg(feature = "impl_smallvec")]
+#[cfg(feature = "smallvec")]
 impl SmallYabf {
     /// Construct an empty bit field with enough capacity pre-allocated to store at least `n`
     /// bits.
@@ -422,7 +454,11 @@ impl SmallYabf {
             for _i in old_word..word - 1 {
                 self.internals.push(0);
             }
-            self.internals.push(bit_mask);
+            if state {
+                self.internals.push(bit_mask);
+            } else {
+                self.internals.push(0);
+            }
         } else if state {
             self.internals[word] |= bit_mask;
         } else {
@@ -475,7 +511,7 @@ impl SmallYabf {
     }
 }
 
-#[cfg(feature = "impl_smallvec")]
+#[cfg(feature = "smallvec")]
 /// Iterator over the bits set to true in the bit field container.
 /// Will iterate over the bits from lowest to to highest.
 /// This is a relatively expensive O(size of container) operation.
@@ -488,7 +524,7 @@ pub struct SmallYabfIterator<'s> {
     last_bit: usize,
 }
 
-#[cfg(feature = "impl_smallvec")]
+#[cfg(feature = "smallvec")]
 impl<'s> SmallYabfIterator<'s> {
     pub(crate) fn new(yabf: &'s SmallYabf) -> Self {
         Self {
@@ -499,7 +535,7 @@ impl<'s> SmallYabfIterator<'s> {
     }
 }
 
-#[cfg(feature = "impl_smallvec")]
+#[cfg(feature = "smallvec")]
 impl<'a> IntoIterator for &'a SmallYabf {
     type Item = usize;
     type IntoIter = SmallYabfIterator<'a>;
@@ -509,7 +545,7 @@ impl<'a> IntoIterator for &'a SmallYabf {
     }
 }
 
-#[cfg(feature = "impl_smallvec")]
+#[cfg(feature = "smallvec")]
 impl<'s> Iterator for SmallYabfIterator<'s> {
     type Item = usize;
 
@@ -571,7 +607,7 @@ impl<'s> Iterator for SmallYabfIterator<'s> {
     }
 }
 
-#[cfg(feature = "impl_smallvec")]
+#[cfg(feature = "smallvec")]
 impl fmt::Debug for SmallYabf {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         if self.internals.is_empty() {
@@ -586,17 +622,7 @@ impl fmt::Debug for SmallYabf {
     }
 }
 
-#[cfg(feature = "impl_smallvec")]
-impl Default for SmallYabf {
-    #[inline]
-    fn default() -> Self {
-        Self {
-            internals: smallvec::SmallVec::<[u32; 4]>::default(),
-        }
-    }
-}
-
-#[cfg(feature = "impl_smallvec")]
+#[cfg(feature = "smallvec")]
 /// bit or assign operation
 /// This is a relatively expensive O(size of container) operation.
 /// ```
@@ -695,14 +721,26 @@ mod test {
         assert!(a.bit(44));
         assert!(a.bit(4444));
     }
+
+    #[test]
+    fn readme_1() {
+        use crate::Yabf;
+        let mut a = Yabf::default();
+        let mut b = Yabf::with_capacity(12345);
+        // bits are false by default
+        assert_eq!(a.bit(45), false);
+        a.set_bit(12345, true);
+        assert_eq!(a.bit(12345), true);
+        b.set_bit(345, true);
+        assert_eq!(b.bit(345), true);
+    }
 }
 
-#[cfg(feature = "impl_smallvec")]
+#[cfg(feature = "smallvec")]
 #[cfg(test)]
 mod test_small {
 
     #[test]
-    #[cfg(feature = "impl_smallvec")]
     fn test_capacity_0() {
         let mut bf = crate::SmallYabf::default();
 
@@ -726,7 +764,6 @@ mod test_small {
     }
 
     #[test]
-    #[cfg(feature = "impl_smallvec")]
     fn test_capacity_1() {
         let bf = crate::SmallYabf::with_capacity(100);
         assert!(bf.is_empty());
@@ -734,7 +771,6 @@ mod test_small {
     }
 
     #[test]
-    #[cfg(feature = "impl_smallvec")]
     fn test_capacity_2() {
         let mut bf = crate::SmallYabf::default();
         assert!(bf.is_empty());
@@ -745,7 +781,6 @@ mod test_small {
     }
 
     #[test]
-    #[cfg(feature = "impl_smallvec")]
     fn test_iter() {
         let mut bf = crate::SmallYabf::default();
         bf.set_bit(129, true);
@@ -755,4 +790,16 @@ mod test_small {
         bf.set_bit(167, true);
         println!("{:?}", bf.into_iter().collect::<Vec<usize>>());
     }
+
+    #[test]
+    fn readme_2() {
+        use crate::SmallYabf;
+        let mut a = SmallYabf::default();
+        let mut b = SmallYabf::with_capacity(12345);
+        a.set_bit(45, false);
+        b.set_bit(12345, true);
+        assert_eq!(a.bit(45), false);
+        assert_eq!(b.bit(12345), true);
+        assert_eq!(a.bit(12345), false);
+    }
 }
